@@ -1,23 +1,26 @@
 /* Subclasses of built-in Python types supporting extra D-Bus functionality.
  *
- * Copyright (C) 2006, 2007 Collabora Ltd.
+ * Copyright (C) 2006-2007 Collabora Ltd. <http://www.collabora.co.uk/>
  *
- * Licensed under the Academic Free License version 2.1
+ * Permission is hereby granted, free of charge, to any person
+ * obtaining a copy of this software and associated documentation
+ * files (the "Software"), to deal in the Software without
+ * restriction, including without limitation the rights to use, copy,
+ * modify, merge, publish, distribute, sublicense, and/or sell copies
+ * of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2.1 of the License, or
- * (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * The above copyright notice and this permission notice shall be
+ * included in all copies or substantial portions of the Software.
  *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+ * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+ * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+ * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+ * DEALINGS IN THE SOFTWARE.
  */
 
 #include <Python.h>
@@ -47,7 +50,7 @@ dbus_py_variant_level_get(PyObject *obj)
     }
 
     vl_obj = PyDict_GetItem(_dbus_py_variant_levels, key);
-    Py_DECREF(key);
+    Py_CLEAR(key);
 
     if (!vl_obj)
         return 0;
@@ -67,7 +70,7 @@ dbus_py_variant_level_set(PyObject *obj, long variant_level)
     if (variant_level <= 0) {
         if (PyDict_GetItem (_dbus_py_variant_levels, key)) {
             if (PyDict_DelItem (_dbus_py_variant_levels, key) < 0) {
-                Py_DECREF(key);
+                Py_CLEAR(key);
                 return FALSE;
             }
         }
@@ -75,15 +78,15 @@ dbus_py_variant_level_set(PyObject *obj, long variant_level)
     else {
         PyObject *vl_obj = PyInt_FromLong(variant_level);
         if (!vl_obj) {
-            Py_DECREF(key);
+            Py_CLEAR(key);
             return FALSE;
         }
         if (PyDict_SetItem (_dbus_py_variant_levels, key, vl_obj) < 0) {
-            Py_DECREF(key);
+            Py_CLEAR(key);
             return FALSE;
         }
     }
-    Py_DECREF(key);
+    Py_CLEAR(key);
     return TRUE;
 }
 
@@ -108,11 +111,11 @@ dbus_py_variant_level_getattro(PyObject *obj, PyObject *name)
 
     if (strcmp(PyString_AS_STRING(name), "variant_level")) {
         value = PyObject_GenericGetAttr(obj, name);
-        Py_DECREF(name);
+        Py_CLEAR(name);
         return value;
     }
 
-    Py_DECREF(name);
+    Py_CLEAR(name);
 
     key = PyLong_FromVoidPtr(obj);
 
@@ -121,7 +124,7 @@ dbus_py_variant_level_getattro(PyObject *obj, PyObject *name)
     }
 
     value = PyDict_GetItem(_dbus_py_variant_levels, key);
-    Py_DECREF(key);
+    Py_CLEAR(key);
 
     if (!value)
         return PyInt_FromLong(0);
@@ -207,7 +210,7 @@ DBusPythonInt_tp_repr(PyObject *self)
                                       PyString_AS_STRING(parent_repr));
     }
     /* whether my_repr is NULL or not: */
-    Py_DECREF(parent_repr);
+    Py_CLEAR(parent_repr);
     return my_repr;
 }
 
@@ -319,7 +322,7 @@ DBusPythonFloat_tp_repr(PyObject *self)
                                       PyString_AS_STRING(parent_repr));
     }
     /* whether my_repr is NULL or not: */
-    Py_DECREF(parent_repr);
+    Py_CLEAR(parent_repr);
     return my_repr;
 }
 
@@ -396,7 +399,7 @@ DBusPythonString_tp_new(PyTypeObject *cls, PyObject *args, PyObject *kwargs)
     self = (PyString_Type.tp_new)(cls, args, NULL);
     if (self) {
         if (!dbus_py_variant_level_set(self, variantness)) {
-            Py_DECREF(self);
+            Py_CLEAR(self);
             return NULL;
         }
     }
@@ -414,11 +417,11 @@ DBusPythonString_tp_repr(PyObject *self)
     if (!parent_repr) return NULL;
     vl_obj = PyObject_GetAttr(self, dbus_py_variant_level_const);
     if (!vl_obj) {
-        Py_DECREF(parent_repr);
+        Py_CLEAR(parent_repr);
         return NULL;
     }
     variant_level = PyInt_AsLong(vl_obj);
-    Py_DECREF(vl_obj);
+    Py_CLEAR(vl_obj);
     if (variant_level > 0) {
         my_repr = PyString_FromFormat("%s(%s, variant_level=%ld)",
                                       self->ob_type->tp_name,
@@ -430,7 +433,7 @@ DBusPythonString_tp_repr(PyObject *self)
                                       PyString_AS_STRING(parent_repr));
     }
     /* whether my_repr is NULL or not: */
-    Py_DECREF(parent_repr);
+    Py_CLEAR(parent_repr);
     return my_repr;
 }
 
@@ -514,7 +517,7 @@ DBusPythonLong_tp_new(PyTypeObject *cls, PyObject *args, PyObject *kwargs)
     self = (PyLong_Type.tp_new)(cls, args, NULL);
     if (self) {
         if (!dbus_py_variant_level_set(self, variantness)) {
-            Py_DECREF(self);
+            Py_CLEAR(self);
             return NULL;
         }
     }
@@ -532,11 +535,11 @@ DBusPythonLong_tp_repr(PyObject *self)
     if (!parent_repr) return NULL;
     vl_obj = PyObject_GetAttr(self, dbus_py_variant_level_const);
     if (!vl_obj) {
-        Py_DECREF(parent_repr);
+        Py_CLEAR(parent_repr);
         return NULL;
     }
     variant_level = PyInt_AsLong(vl_obj);
-    Py_DECREF(vl_obj);
+    Py_CLEAR(vl_obj);
     if (variant_level) {
         my_repr = PyString_FromFormat("%s(%s, variant_level=%ld)",
                                       self->ob_type->tp_name,
@@ -548,7 +551,7 @@ DBusPythonLong_tp_repr(PyObject *self)
                                       PyString_AS_STRING(parent_repr));
     }
     /* whether my_repr is NULL or not: */
-    Py_DECREF(parent_repr);
+    Py_CLEAR(parent_repr);
     return my_repr;
 }
 
@@ -644,6 +647,7 @@ dbus_py_init_abstract(void)
 dbus_bool_t
 dbus_py_insert_abstract_types(PyObject *this_module)
 {
+    /* PyModule_AddObject steals a ref */
     Py_INCREF(&DBusPyIntBase_Type);
     Py_INCREF(&DBusPyLongBase_Type);
     Py_INCREF(&DBusPyStrBase_Type);
