@@ -1,23 +1,26 @@
 /* D-Bus Byte and ByteArray types.
  *
- * Copyright (C) 2006 Collabora Ltd.
+ * Copyright (C) 2006 Collabora Ltd. <http://www.collabora.co.uk/>
  *
- * Licensed under the Academic Free License version 2.1
+ * Permission is hereby granted, free of charge, to any person
+ * obtaining a copy of this software and associated documentation
+ * files (the "Software"), to deal in the Software without
+ * restriction, including without limitation the rights to use, copy,
+ * modify, merge, publish, distribute, sublicense, and/or sell copies
+ * of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2.1 of the License, or
- * (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * The above copyright notice and this permission notice shall be
+ * included in all copies or substantial portions of the Software.
  *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+ * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+ * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+ * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+ * DEALINGS IN THE SOFTWARE.
  */
 
 #include <Python.h>
@@ -101,12 +104,10 @@ Byte_new(PyTypeObject *cls, PyObject *args, PyObject *kwargs)
 
     tuple = Py_BuildValue("(O)", obj);
     if (!tuple) return NULL;
-    Py_DECREF(obj);
-    obj = NULL;
+    Py_CLEAR(obj);
 
     obj = DBusPyIntBase_Type.tp_new(cls, tuple, kwargs);
-    Py_DECREF(tuple);
-    tuple = NULL;
+    Py_CLEAR(tuple);
     return obj;
 
 bad_arg:
@@ -251,6 +252,7 @@ dbus_py_init_byte_types(void)
 dbus_bool_t
 dbus_py_insert_byte_types(PyObject *this_module)
 {
+    /* PyModule_AddObject steals a ref */
     Py_INCREF(&DBusPyByte_Type);
     if (PyModule_AddObject(this_module, "Byte",
                            (PyObject *)&DBusPyByte_Type) < 0) return 0;
