@@ -478,31 +478,29 @@ Message_get_path_decomposed(Message *self, PyObject *unused UNUSED)
 
     if (!ret) return NULL;
     if (!self->msg) {
-        Py_DECREF(ret);
+        Py_CLEAR(ret);
         return DBusPy_RaiseUnusableMessage();
     }
     if (!dbus_message_get_path_decomposed(self->msg, &paths)) {
-        Py_DECREF(ret);
+        Py_CLEAR(ret);
         return PyErr_NoMemory();
     }
     if (!paths) {
-        Py_DECREF(ret);
+        Py_CLEAR(ret);
         Py_RETURN_NONE;
     }
     for (ptr = paths; *ptr; ptr++) {
         PyObject *str = PyString_FromString(*ptr);
 
         if (!str) {
-            Py_DECREF(ret);
-            ret = NULL;
+            Py_CLEAR(ret);
             break;
         }
         if (PyList_Append(ret, str) < 0) {
-            Py_DECREF(ret);
-            ret = NULL;
+            Py_CLEAR(ret);
             break;
         }
-        Py_DECREF(str);
+        Py_CLEAR(str);
         str = NULL;
     }
     dbus_free_string_array(paths);
@@ -1042,6 +1040,13 @@ dbus_py_init_message_types(void)
 dbus_bool_t
 dbus_py_insert_message_types(PyObject *this_module)
 {
+    /* PyModule_AddObject steals a ref */
+    Py_INCREF (&MessageType);
+    Py_INCREF (&MethodCallMessageType);
+    Py_INCREF (&MethodReturnMessageType);
+    Py_INCREF (&ErrorMessageType);
+    Py_INCREF (&SignalMessageType);
+
     if (PyModule_AddObject(this_module, "Message",
                          (PyObject *)&MessageType) < 0) return 0;
 
