@@ -1,23 +1,26 @@
 /* Simple D-Bus types: ObjectPath and other string types.
  *
- * Copyright (C) 2006, 2007 Collabora Ltd.
+ * Copyright (C) 2006-2007 Collabora Ltd. <http://www.collabora.co.uk/>
  *
- * Licensed under the Academic Free License version 2.1
+ * Permission is hereby granted, free of charge, to any person
+ * obtaining a copy of this software and associated documentation
+ * files (the "Software"), to deal in the Software without
+ * restriction, including without limitation the rights to use, copy,
+ * modify, merge, publish, distribute, sublicense, and/or sell copies
+ * of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2.1 of the License, or
- * (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * The above copyright notice and this permission notice shall be
+ * included in all copies or substantial portions of the Software.
  *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+ * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+ * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+ * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+ * DEALINGS IN THE SOFTWARE.
  */
 
 #include "types-internal.h"
@@ -74,7 +77,7 @@ UTF8String_tp_new(PyTypeObject *cls, PyObject *args, PyObject *kwargs)
                                      &str, &variantness)) return NULL;
     unicode = PyUnicode_DecodeUTF8(str, strlen(str), NULL);
     if (!unicode) return NULL;
-    Py_DECREF(unicode);
+    Py_CLEAR(unicode);
     return (DBusPyStrBase_Type.tp_new)(cls, args, kwargs);
 }
 
@@ -282,7 +285,7 @@ String_tp_repr(PyObject *self)
                                       PyString_AS_STRING(parent_repr));
     }
     /* whether my_repr is NULL or not: */
-    Py_DECREF(parent_repr);
+    Py_CLEAR(parent_repr);
     return my_repr;
 }
 
@@ -361,6 +364,7 @@ dbus_py_init_string_types(void)
 dbus_bool_t
 dbus_py_insert_string_types(PyObject *this_module)
 {
+    /* PyModule_AddObject steals a ref */
     Py_INCREF(&DBusPyObjectPath_Type);
     Py_INCREF(&DBusPyUTF8String_Type);
     Py_INCREF(&DBusPyString_Type);
