@@ -1,23 +1,27 @@
-# Copyright (C) 2003, 2004, 2005, 2006, 2007 Red Hat Inc. <http://www.redhat.com/>
+# Copyright (C) 2003-2007 Red Hat Inc. <http://www.redhat.com/>
 # Copyright (C) 2003 David Zeuthen
 # Copyright (C) 2004 Rob Taylor
-# Copyright (C) 2005, 2006, 2007 Collabora Ltd. <http://www.collabora.co.uk/>
+# Copyright (C) 2005-2007 Collabora Ltd. <http://www.collabora.co.uk/>
 #
-# Licensed under the Academic Free License version 2.1
+# Permission is hereby granted, free of charge, to any person
+# obtaining a copy of this software and associated documentation
+# files (the "Software"), to deal in the Software without
+# restriction, including without limitation the rights to use, copy,
+# modify, merge, publish, distribute, sublicense, and/or sell copies
+# of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# The above copyright notice and this permission notice shall be
+# included in all copies or substantial portions of the Software.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+# DEALINGS IN THE SOFTWARE.
 
 import sys
 import logging
@@ -53,7 +57,8 @@ class _DeferredMethod:
         self._block = block
 
     def __call__(self, *args, **keywords):
-        if keywords.has_key('reply_handler'):
+        if (keywords.has_key('reply_handler') or
+            keywords.get('ignore_reply', False)):
             # defer the async call til introspection finishes
             self._append(self._proxy_method, args, keywords)
             return None
@@ -97,30 +102,33 @@ class _ProxyMethod:
         reply_handler = keywords.pop('reply_handler', None)
         error_handler = keywords.pop('error_handler', None)
         ignore_reply = keywords.pop('ignore_reply', False)
+        signature = keywords.pop('signature', None)
 
         if reply_handler is not None or error_handler is not None:
             if reply_handler is None:
-                raise MissingErrorHandlerException()
-            elif error_handler is None:
                 raise MissingReplyHandlerException()
+            elif error_handler is None:
+                raise MissingErrorHandlerException()
             elif ignore_reply:
                 raise TypeError('ignore_reply and reply_handler cannot be '
                                 'used together')
 
         dbus_interface = keywords.pop('dbus_interface', self._dbus_interface)
 
-        if dbus_interface is None:
-            key = self._method_name
-        else:
-            key = dbus_interface + '.' + self._method_name
-        introspect_sig = self._proxy._introspect_method_map.get(key, None)
+        if signature is None:
+            if dbus_interface is None:
+                key = self._method_name
+            else:
+                key = dbus_interface + '.' + self._method_name
+
+            signature = self._proxy._introspect_method_map.get(key, None)
 
         if ignore_reply or reply_handler is not None:
             self._connection.call_async(self._named_service,
                                         self._object_path,
                                         dbus_interface,
                                         self._method_name,
-                                        introspect_sig,
+                                        signature,
                                         args,
                                         reply_handler,
                                         error_handler,
@@ -130,27 +138,29 @@ class _ProxyMethod:
                                                   self._object_path,
                                                   dbus_interface,
                                                   self._method_name,
-                                                  introspect_sig,
+                                                  signature,
                                                   args,
                                                   **keywords)
 
     def call_async(self, *args, **keywords):
         reply_handler = keywords.pop('reply_handler', None)
         error_handler = keywords.pop('error_handler', None)
+        signature = keywords.pop('signature', None)
 
         dbus_interface = keywords.pop('dbus_interface', self._dbus_interface)
 
-        if dbus_interface:
-            key = dbus_interface + '.' + self._method_name
-        else:
-            key = self._method_name
-        introspect_sig = self._proxy._introspect_method_map.get(key, None)
+        if signature is None:
+            if dbus_interface:
+                key = dbus_interface + '.' + self._method_name
+            else:
+                key = self._method_name
+            signature = self._proxy._introspect_method_map.get(key, None)
 
         self._connection.call_async(self._named_service,
                                     self._object_path,
                                     dbus_interface,
                                     self._method_name,
-                                    introspect_sig,
+                                    signature,
                                     args,
                                     reply_handler,
                                     error_handler,
@@ -371,6 +381,7 @@ class ProxyObject(object):
         # and do one message per idle
         for (proxy_method, args, keywords) in self._pending_introspect_queue:
             proxy_method(*args, **keywords)
+        self._pending_introspect_queue = []
 
     def _introspect_reply_handler(self, data):
         self._introspect_lock.acquire()
