@@ -26,6 +26,8 @@
 #include <Python.h>
 #include "dbus-python.h"
 
+PyMODINIT_FUNC initdbus_py_test(void);
+
 #if defined(__GNUC__)
 #   if __GNUC__ >= 3
 #       define UNUSED __attribute__((__unused__))
@@ -86,19 +88,19 @@ UnusableMainLoop (PyObject *always_null UNUSED, PyObject *args, PyObject *kwargs
     if (mainloop && set_as_default) {
         if (!_dbus_bindings_module) {
             PyErr_SetString(PyExc_ImportError, "_dbus_bindings not imported");
-            Py_DECREF(mainloop);
+            Py_CLEAR(mainloop);
             return NULL;
         }
         function = PyObject_GetAttrString(_dbus_bindings_module,
                                           "set_default_main_loop");
         if (!function) {
-            Py_DECREF(mainloop);
+            Py_CLEAR(mainloop);
             return NULL;
         }
         result = PyObject_CallFunctionObjArgs(function, mainloop, NULL);
-        Py_DECREF(function);
+        Py_CLEAR(function);
         if (!result) {
-            Py_DECREF(mainloop);
+            Py_CLEAR(mainloop);
             return NULL;
         }
     }
